@@ -3,10 +3,10 @@
 
 -- This files is following a special format compared to other animation scripts.
 
-local ANIM_SOUTH = hoa_map.MapMode.ANIM_SOUTH;
-local ANIM_NORTH = hoa_map.MapMode.ANIM_NORTH;
-local ANIM_WEST = hoa_map.MapMode.ANIM_WEST;
-local ANIM_EAST = hoa_map.MapMode.ANIM_EAST;
+local ANIM_SOUTH = vt_map.MapMode.ANIM_SOUTH;
+local ANIM_NORTH = vt_map.MapMode.ANIM_NORTH;
+local ANIM_WEST = vt_map.MapMode.ANIM_WEST;
+local ANIM_EAST = vt_map.MapMode.ANIM_EAST;
 
 sprite_animation = {
 
